@@ -74,8 +74,8 @@ class BaseLoop(Toolbox):
         scoring: list of Callbale, default is [sklearn.metrics.r2_score,]
             See Also sklearn.metrics
         score_pen: tuple of  1, -1 or float but 0.
-            >0 : best is positive, worse -np.inf
-            <0 : best is negative, worse np.inf
+            >0 : max problem, best is positive, worse -np.inf
+            <0 : min problem, best is negative, worse np.inf
             Notes:
             if multiply score method, the scores must be turn to same dimension in preprocessing
             or weight by score_pen. Because the all the selection are stand on the mean(w_i*score_i)
@@ -108,7 +108,7 @@ class BaseLoop(Toolbox):
             values = {"max": np.max, "mean": np.mean, "min": np.mean, "std": np.std, "sum": np.sum}
             keys = {"fitness": lambda ind: ind.fitness.values[0],
                    "fitness_dim_is_True": lambda ind: ind.fitness.values[0] if ind.y_dim is not dnan else np.nan,
-                   "fitness__dim_is_target": lambda ind: ind.fitness.values[0] if ind.dim_score else np.nan,
+                   "fitness_dim_is_target": lambda ind: ind.fitness.values[0] if ind.dim_score else np.nan,
                    "dim_is_True": lambda ind: 1 if ind.y_dim is not dnan else 0,
                    "dim_is_traget": lambda ind: 1 if ind.dim_score else 0}
             if stats is None:
@@ -178,11 +178,14 @@ class BaseLoop(Toolbox):
             hall = 1
         self.hall = HallOfFame(hall)
 
-        if re_hall is 1 or re_hall is 0:
-            print("re_hall should more than 1")
-            re_hall = 2
-        assert re_hall >= hall, ("re_hall should more than hall")
-        self.re_hall = HallOfFame(re_hall)
+        if re_hall is None:
+            self.re_hall = None
+        else:
+            if re_hall is 1 or re_hall is 0:
+                print("re_hall should more than 1")
+                re_hall = 2
+            assert re_hall >= hall, ("re_hall should more than hall")
+            self.re_hall = HallOfFame(re_hall)
 
     def varAnd(self, *arg, **kwargs):
         return varAnd(*arg, **kwargs)
@@ -219,6 +222,13 @@ class BaseLoop(Toolbox):
 
             inds_dim += [i for i in self.re_hall.items if i not in inds_dim]
         else:
+            if self.cal_dim:
+                inds_dim = self.selKbestDim(population, self.hall.maxsize)
+            else:
+                inds_dim = self.select(population, self.hall.maxsize)
+
+            self.hall.update(inds_dim)
+
             inds_dim = []
 
         inds = copy.deepcopy(inds_dim)
@@ -347,17 +357,21 @@ if __name__ == "__main__":
 
     # symbolset
     pset0 = SymbolSet()
-    pset0.add_features(x, y, x_dim=x_dim, y_dim=y_dim, group=[[1, 2], [4, 5]])
+    pset0.add_features(x, y, x_dim=x_dim, y_dim=y_dim, group=[[1, 2, 3], [4, 5, 6], [7, 8, 9]])
     pset0.add_constants(c, dim=c_dim, prob=None)
     pset0.add_operations(power_categories=(2, 3, 0.5),
-                         categories=("Add", "Mul", "Neg", "Abs"),
+                         categories=("Add", "Mul", "Sub", "Div", "exp"),
                          self_categories=None)
-    a = time.time()
-    bl = MutilMutateLoop(pset=pset0, gen=10, pop=500, hall=1, batch_size=40, re_hall=3, n_jobs=6, mate_prob=0.8,
-                         mutate_prob=0.5,
-                         tq=False,
-                         re_Tree=0, store=True, random_state=4, add_coef=True, cal_dim=True, personal_map="auto")
-    b = time.time()
-    bl.run()
-    c = time.time()
-    print(c - b, b - a, a - z)
+
+    # a = time.time()
+    bl = MutilMutateLoop(pset=pset0, gen=10, pop=500, hall=1, batch_size=40, re_hall=3,
+                         n_jobs=1, mate_prob=0.8, max_value=5,
+                         mutate_prob=0.5, tq=True,
+                         re_Tree=0, store=True, random_state=4,
+                         add_coef=True, cal_dim=True, personal_map="auto")
+    # b = time.time()
+    # bl.run()
+    # c = time.time()
+    # print(c - b, b - a, a - z)
+#
+    population = [bl.PTree(bl.genGrow()) for _ in range(bl.pop)]
