@@ -20,7 +20,7 @@ from sklearn.exceptions import DataConversionWarning
 from sklearn.metrics import r2_score
 from sklearn.utils import check_array
 
-from featurebox.symbol.dim import dim_map, dless
+from featurebox.symbol.dim import dim_map, dless, dnan
 from featurebox.symbol.function import np_map
 from featurebox.symbol.gp import compile_context
 
@@ -165,7 +165,7 @@ def calculate_y(expr01, x, y, terminals, add_coef=True,
         assert y.shape == re.shape
         pre_y = check_array(re, ensure_2d=False)
 
-    except (DataConversionWarning, AssertionError, ValueError, AttributeError):
+    except (DataConversionWarning, AssertionError, ValueError, AttributeError, KeyError):
         pre_y = None
 
     return pre_y, expr01
@@ -267,7 +267,10 @@ def calcualte_dim(expr01, terminals, dim_list, y_dim, dim_maps=None):
     if not dim_maps:
         dim_maps = dim_map()
     func0 = sympy.utilities.lambdify(terminals, expr01, modules=[dim_maps])
-    dim_ = func0(*dim_list)
+    try:
+        dim_ = func0(*dim_list)
+    except ValueError:
+        dim_ = dnan
     if isinstance(dim_, float):
         dim_ = dless
     if dim_ in y_dim:
